@@ -1,5 +1,5 @@
 from graphviz import Digraph
-from abstract.model_exporting_strategy import ModelExportingStrategy
+from pythautomata.abstract.model_exporting_strategy import ModelExportingStrategy
 
 
 class WFAImageExporter(ModelExportingStrategy):
